==> x20246935cpplib-0.1.tar.gz: x20246935cpplib-0.1/setup.py <==
from distutils.core import setup
setup(
  name = 'x20246935cpplib',         # How you named your package folder (MyLib)
  packages = ['x20246935cpplib'],   # Chose the same as "name"
  version = '0.1',      # Start with a small number and increase it with every change you make
  license='MIT',        # Chose a license from here: https://help.github.com/articles/licensing-a-repository
  description = 'Library for uniquecode generation',   # Give a short description about your library
  author = 'x20246935',                   # Type in your name
  author_email = 'x20246935@student.ncirl.ie',      # Type in your E-Mail
  url = 'https://github.com/kamalnyadav/x20246935cpplib',   # Provide either the link to your github or to your website
  download_url = 'https://github.com/kamalnyadav/x20246935cpplib/archive/refs/tags/v_01.tar.gz',    # I explain this later on
  keywords = ['UNIQUE'],   # Keywords that define your package best
  install_requires=[            # I get to this in a second
          'validators',
          'beautifulsoup4',
          'time',
      ],
  classifiers=[
    'Development Status :: 3 - Alpha',      # Chose either "3 - Alpha", "4 - Beta" or "5 - Production/Stable" as the current state of your package
    'Intended Audience :: Developers',      # Define that your audience are developers
    'Topic :: Software Development :: Build Tools',
    'License :: OSI Approved :: MIT License',   # Again, pick a license
    'Programming Language :: Python :: 3',      #Specify which pyhton versions that you want to support
    'Programming Language :: Python :: 3.4',
    'Programming Language :: Python :: 3.5',
    'Programming Language :: Python :: 3.6',
    'Programming Language :: Python :: 3.7',
    'Programming Language :: Python :: 3.8',
  ],
)

==> x20246935cpplib-0.2.tar.gz: x20246935cpplib-0.2/setup.py <==
from distutils.core import setup
setup(
  name = 'x20246935cpplib',         # How you named your package folder (MyLib)
  packages = ['x20246935cpplib'],   # Chose the same as "name"
  version = '0.2',      # Start with a small number and increase it with every change you make
  license='MIT',        # Chose a license from here: https://help.github.com/articles/licensing-a-repository
  description = 'Library for uniquecode generation',   # Give a short description about your library
  author = 'x20246935',                   # Type in your name
  author_email = 'x20246935@student.ncirl.ie',      # Type in your E-Mail
  url = 'https://github.com/kamalnyadav/x20246935cpplib',   # Provide either the link to your github or to your website
  download_url = 'https://github.com/kamalnyadav/x20246935cpplib/archive/refs/tags/v_02.tar.gz',    # I explain this later on
  keywords = ['UNIQUE'],   # Keywords that define your package best
  install_requires=['time',
      ],
  classifiers=[
    'Development Status :: 3 - Alpha',      # Chose either "3 - Alpha", "4 - Beta" or "5 - Production/Stable" as the current state of your package
    'Intended Audience :: Developers',      # Define that your audience are developers
    'Topic :: Software Development :: Build Tools',
    'License :: OSI Approved :: MIT License',   # Again, pick a license
    'Programming Language :: Python :: 3',      #Specify which pyhton versions that you want to support
    'Programming Language :: Python :: 3.4',
    'Programming Language :: Python :: 3.5',
    'Programming Language :: Python :: 3.6',
    'Programming Language :: Python :: 3.7',
    'Programming Language :: Python :: 3.8',
  ],
)
